==> atoms-1.0.0-rc1.tar.gz: atoms/src/Plugin/Derivative/DynamicLocalTasks.php <==
<?php

namespace Drupal\atoms\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Defines dynamic local tasks.
 */
class DynamicLocalTasks extends DeriverBase
{

  use StringTranslationTrait;

  private $storage;

  private $transliteration;

  private $categories;

  public function __construct()
  {
    $this->storage = \Drupal::service('atoms.storage');
    $this->transliteration = \Drupal::service('transliteration');
    $this->categories = $this->storage->getCategories();
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition)
  {
    $this->derivatives['atoms'] = $base_plugin_definition;
    $this->derivatives['atoms']['title'] = $this->t('Atoms');
    $this->derivatives['atoms']['route_name'] = 'atoms.overview';
    $this->derivatives['atoms']['base_route'] = "system.admin_content";

    $this->derivatives['atoms.overview.list'] = $base_plugin_definition;
    $this->derivatives['atoms.overview.list']['title'] = $this->t('Table');
    $this->derivatives['atoms.overview.list']['parent_id'] = 'atoms.local_tasks:atoms';
    $this->derivatives['atoms.overview.list']['route_name'] = 'atoms.overview';

    $this->derivatives['atoms.overview.detail'] = $base_plugin_definition;
    $this->derivatives['atoms.overview.detail']['title'] = $this->t('Detail');
    $this->derivatives['atoms.overview.detail']['parent_id'] = 'atoms.local_tasks:atoms';
    $this->derivatives['atoms.overview.detail']['route_name'] = 'atoms.overview.detail';
    $this->derivatives['atoms.overview.detail']['base_route'] = "system.admin_content";

    return $this->derivatives;
  }

  /**
   * @param $string
   *
   * @return string
   */
  private function createRouteId($string)
  {
    $result = $this->transliteration->transliterate($string, LanguageInterface::LANGCODE_DEFAULT, '_');
    $result = strtolower($result);
    $result = preg_replace('/[^a-z0-9_]+/', '_', $result);
    $result = preg_replace('/_+/', '_', $result);
    return $result;
  }

  private function buildRoute($id, $category, $base_plugin_definition)
  {
    $route = [
      'title' => $this->t($category),
      'route_name' => 'atoms.collection.category',
      'parent_id' => 'atoms.local_tasks:atoms.overview',
      'route_parameters' => ['category_id' => $id],
    ];

    return array_merge($base_plugin_definition, $route);
  }
}

==> atoms-1.0.1.tar.gz: atoms/src/Plugin/Derivative/DynamicLocalTasks.php <==
<?php

namespace Drupal\atoms\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Defines dynamic local tasks.
 */
class DynamicLocalTasks extends DeriverBase {

  use StringTranslationTrait;

  /**
   * The atoms storage service.
   *
   * @var \Drupal\atoms\AtomsStorage
   */
  private $storage;

  /**
   * The transliteration service.
   *
   * @var \Drupal\Component\Transliteration\TransliterationInterface
   */
  private $transliteration;

  /**
   * Array of all atom categories.
   *
   * @var array
   */
  private $categories;

  /**
   * Construct a DynamicLocalTasks object.
   */
  public function __construct() {
    $this->storage = \Drupal::service('atoms.storage');
    $this->transliteration = \Drupal::service('transliteration');
    $this->categories = $this->storage->getCategories();
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $this->derivatives['atoms'] = $base_plugin_definition;
    $this->derivatives['atoms']['title'] = $this->t('Atoms');
    $this->derivatives['atoms']['route_name'] = 'atoms.overview';
    $this->derivatives['atoms']['base_route'] = "system.admin_content";

    $this->derivatives['atoms.overview.list'] = $base_plugin_definition;
    $this->derivatives['atoms.overview.list']['title'] = $this->t('Table');
    $this->derivatives['atoms.overview.list']['parent_id'] = 'atoms.local_tasks:atoms';
    $this->derivatives['atoms.overview.list']['route_name'] = 'atoms.overview';

    $this->derivatives['atoms.overview.detail'] = $base_plugin_definition;
    $this->derivatives['atoms.overview.detail']['title'] = $this->t('Detail');
    $this->derivatives['atoms.overview.detail']['parent_id'] = 'atoms.local_tasks:atoms';
    $this->derivatives['atoms.overview.detail']['route_name'] = 'atoms.overview.detail';
    $this->derivatives['atoms.overview.detail']['base_route'] = "system.admin_content";

    return $this->derivatives;
  }

}
